@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,7 +10,6 @@
 #include <asiolink/io_service.h>
 #include <cc/command_interpreter.h>
 #include <config/command_mgr.h>
-#include <config/unix_command_config.h>
 #include <config/timeouts.h>
 #include <dhcp/dhcp4.h>
 #include <dhcp/libdhcp++.h>
@@ -22,7 +21,6 @@
 #include <dhcp4/tests/dhcp4_test_utils.h>
 #include <hooks/hooks_manager.h>
 #include <log/logger_support.h>
-#include <process/log_parser.h>
 #include <stats/stats_mgr.h>
 #include <util/multi_threading_mgr.h>
 #include <util/chrono_time_utils.h>
@@ -55,7 +53,6 @@ using namespace isc::hooks;
 using namespace isc::stats;
 using namespace isc::test;
 using namespace isc::util;
-using namespace isc::process;
 namespace ph = std::placeholders;
 
 namespace {
@@ -89,7 +86,7 @@ private:
 class NakedControlledDhcpv4Srv: public ControlledDhcpv4Srv {
     // "Naked" DHCPv4 server, exposes internal fields
 public:
-    NakedControlledDhcpv4Srv() : ControlledDhcpv4Srv(0) {
+    NakedControlledDhcpv4Srv():ControlledDhcpv4Srv(0) {
         CfgMgr::instance().setFamily(AF_INET);
     }
 
@@ -106,28 +103,24 @@ public:
     /// @brief Path to the UNIX socket being used to communicate with the server
     std::string socket_path_;
 
-    /// @brief List of interfaces (defaults to "*").
-    std::string interfaces_;
-
     /// @brief Pointer to the tested server object
     boost::shared_ptr<NakedControlledDhcpv4Srv> server_;
 
     /// @brief Default constructor
     ///
     /// Sets socket path to its default value.
-    CtrlChannelDhcpv4SrvTest() : interfaces_("\"*\"") {
-        resetLogPath();
-        setSocketTestPath();
+    CtrlChannelDhcpv4SrvTest() {
+        const char* env = getenv("KEA_SOCKET_TEST_DIR");
+        if (env) {
+            socket_path_ = string(env) + "/kea4.sock";
+        } else {
+            socket_path_ = sandbox.join("kea4.sock");
+        }
         reset();
-        IfaceMgr::instance().setTestMode(false);
-        IfaceMgr::instance().setDetectCallback(std::bind(&IfaceMgr::checkDetectIfaces,
-                                               IfaceMgr::instancePtr().get(), ph::_1));
     }
 
     /// @brief Destructor
     ~CtrlChannelDhcpv4SrvTest() {
-        resetLogPath();
-        Dhcpv4SrvTest::resetSocketPath();
         LeaseMgrFactory::destroy();
         StatsMgr::instance().removeAll();
 
@@ -136,33 +129,8 @@ public:
         CommandMgr::instance().setConnectionTimeout(TIMEOUT_DHCP_SERVER_RECEIVE_COMMAND);
 
         server_.reset();
-        IfaceMgr::instance().setTestMode(false);
-        IfaceMgr::instance().setDetectCallback(std::bind(&IfaceMgr::checkDetectIfaces,
-                                               IfaceMgr::instancePtr().get(), ph::_1));
-        IfaceMgr::instance().clearIfaces();
-        IfaceMgr::instance().closeSockets();
-        IfaceMgr::instance().detectIfaces();
     };
 
-    /// @brief Sets the log path where log output may be written.
-    /// @param explicit_path path to use as the log path.
-    void setLogTestPath(const std::string explicit_path = "") {
-        LogConfigParser::getLogPath(true, (!explicit_path.empty() ?
-                                           explicit_path : TEST_DATA_BUILDDIR));
-    }
-
-    /// @brief Resets the log path to TEST_DATA_BUILDDIR.
-    void resetLogPath() {
-        LogConfigParser::getLogPath(true);
-    }
-
-    /// @brief Sets the path in which the socket can be created.
-    /// @param explicit_path path to use as the socket path.
-    void setSocketTestPath(const std::string explicit_path = "") {
-        Dhcpv4SrvTest::setSocketTestPath(explicit_path);
-        socket_path_ = UnixCommandConfig::getSocketPath() + "/kea4.sock";
-    }
-
     /// @brief Returns pointer to the server's IO service.
     ///
     /// @return Pointer to the server's IO service or null pointer if the server
@@ -179,9 +147,7 @@ public:
         std::string header =
             "{"
             "    \"interfaces-config\": {"
-            "        \"interfaces\": [";
-
-        std::string body = "]"
+            "        \"interfaces\": [ \"*\" ]"
             "    },"
             "    \"expired-leases-processing\": {"
             "         \"reclaim-timer-wait-time\": 60,"
@@ -209,7 +175,8 @@ public:
 
         // Fill in the socket-name value with socket_path_  to
         // make the actual configuration text.
-        std::string config_txt = header + interfaces_ + body + socket_path_  + footer;
+        std::string config_txt = header + socket_path_  + footer;
+
         ASSERT_NO_THROW(server_.reset(new NakedControlledDhcpv4Srv()));
 
         ConstElementPtr config;
@@ -243,6 +210,7 @@ public:
         ASSERT_GT(isc::config::CommandMgr::instance().getControlSocketFD(), -1);
     }
 
+
     /// @brief Reset hooks data
     ///
     /// Resets the data for the hooks-related portion of the test by ensuring
@@ -469,7 +437,6 @@ TEST_F(CtrlChannelDhcpv4SrvTest, commands) {
 // Check that the "libreload" command will reload libraries
 TEST_F(CtrlChannelDhcpv4SrvTest, libreload) {
     createUnixChannelServer();
-    ASSERT_TRUE(DHCP4_HOOKS_TEST_PATH);  // suppress unused warning.
 
     // Ensure no marker files to start with.
     ASSERT_FALSE(checkMarkerFileExists(LOAD_MARKER_FILE));
@@ -755,7 +722,6 @@ TEST_F(CtrlChannelDhcpv4SrvTest, controlChannelStats) {
 
 // Check that the "config-set" command will replace current configuration
 TEST_F(CtrlChannelDhcpv4SrvTest, configSet) {
-    setLogTestPath("/dev");
     createUnixChannelServer();
 
     // Define strings to permutate the config arguments
@@ -824,7 +790,7 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configSet) {
         "       ,\"loggers\": [ { \n"
         "            \"name\": \"kea\", \n"
         "            \"severity\": \"FATAL\", \n"
-        "            \"output_options\": [{ \n"
+        "            \"output-options\": [{ \n"
         "                \"output\": \"/dev/null\" \n"
         "            }] \n"
         "        }] \n";
@@ -851,7 +817,7 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configSet) {
     sendUnixCommand(os.str(), response);
 
     // Verify the configuration was successful. The config contains random
-    // socket name (/tmp/kea-<value-changing-each-time>/kea4.sock), so the
+    // socket name (/tmp/kea-<value-changing-each-time>/kea6.sock), so the
     // hash will be different each time. As such, we can do simplified checks:
     // - verify the "result": 0 is there
     // - verify the "text": "Configuration successful." is there
@@ -919,7 +885,7 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configSet) {
     EXPECT_FALSE(fileExists(socket_path_));
 
     // With no command channel, should still receive the response. The config contains random
-    // socket name (/tmp/kea-<value-changing-each-time>/kea4.sock), so the
+    // socket name (/tmp/kea-<value-changing-each-time>/kea6.sock), so the
     // hash will be different each time. As such, we can do simplified checks:
     // - verify the "result": 0 is there
     // - verify the "text": "Configuration successful." is there
@@ -992,7 +958,6 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configHashGet) {
 
 // Verify that the "config-test" command will do what we expect.
 TEST_F(CtrlChannelDhcpv4SrvTest, configTest) {
-    setLogTestPath("/dev");
     createUnixChannelServer();
 
     // Define strings to permutate the config arguments
@@ -1040,7 +1005,7 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configTest) {
         "       ,\"loggers\": [ { \n"
         "            \"name\": \"kea\", \n"
         "            \"severity\": \"FATAL\", \n"
-        "            \"output_options\": [{ \n"
+        "            \"output-options\": [{ \n"
         "                \"output\": \"/dev/null\" \n"
         "            }] \n"
         "        }] \n";
@@ -1065,7 +1030,7 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configTest) {
     sendUnixCommand(os.str(), response);
 
     // Verify the configuration was successful. The config contains random
-    // socket name (/tmp/kea-<value-changing-each-time>/kea4.sock), so the
+    // socket name (/tmp/kea-<value-changing-each-time>/kea6.sock), so the
     // hash will be different each time. As such, we can do simplified checks:
     // - verify the "result": 0 is there
     // - verify the "text": "Configuration successful." is there
@@ -1541,67 +1506,12 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configWriteFilename) {
     createUnixChannelServer();
     std::string response;
 
-    // This is normally set by the command line -c parameter.
-    server_->setConfigFile("test1.json");
-
     sendUnixCommand("{ \"command\": \"config-write\", "
                     "\"arguments\": { \"filename\": \"test2.json\" } }", response);
-
     checkConfigWrite(response, CONTROL_RESULT_SUCCESS, "test2.json");
     ::remove("test2.json");
 }
 
-// Tests if config-write can be called with a valid full path as parameter.
-TEST_F(CtrlChannelDhcpv4SrvTest, configWriteFullPath) {
-    createUnixChannelServer();
-    std::string response;
-
-    // This is normally set by the command line -c parameter.
-    server_->setConfigFile("/tmp/test1.json");
-
-    sendUnixCommand("{ \"command\": \"config-write\", "
-                    "\"arguments\": { \"filename\": \"/tmp/test2.json\" } }", response);
-
-    checkConfigWrite(response, CONTROL_RESULT_SUCCESS, "/tmp/test2.json");
-    ::remove("/tmp/test2.json");
-}
-
-// Tests if config-write raises an error with invalid path as parameter.
-TEST_F(CtrlChannelDhcpv4SrvTest, configWriteBadPath) {
-    createUnixChannelServer();
-    std::string response;
-
-    // This is normally set by the command line -c parameter.
-    server_->setConfigFile("test1.json");
-
-    sendUnixCommand("{ \"command\": \"config-write\", "
-                    "\"arguments\": { \"filename\": \"/tmp/test2.json\" } }", response);
-
-    string expected = "not allowed to write config into /tmp/test2.json: ";
-    expected += "file /tmp/test2.json must be in the same directory ";
-    expected += "as the config file (test1.json)";
-    checkConfigWrite(response, CONTROL_RESULT_ERROR, expected);
-    ::remove("/tmp/test2.json");
-}
-
-// Tests if config-write raises an error with invalid full path as parameter.
-TEST_F(CtrlChannelDhcpv4SrvTest, configWriteBadFullPath) {
-    createUnixChannelServer();
-    std::string response;
-
-    // This is normally set by the command line -c parameter.
-    server_->setConfigFile("/tmp/kea1/test.json");
-
-    sendUnixCommand("{ \"command\": \"config-write\", "
-                    "\"arguments\": { \"filename\": \"/tmp/kea2/test.json\" } }", response);
-
-    string expected = "not allowed to write config into /tmp/kea2/test.json: ";
-    expected += "file /tmp/kea2/test.json must be in the same directory ";
-    expected += "as the config file (/tmp/kea1/test.json)";
-    checkConfigWrite(response, CONTROL_RESULT_ERROR, expected);
-    ::remove("/tmp/kea2/test.json");
-}
-
 // Tests if config-reload attempts to reload a file and reports that the
 // file is missing.
 TEST_F(CtrlChannelDhcpv4SrvTest, configReloadMissingFile) {
@@ -1681,85 +1591,8 @@ TEST_F(CtrlChannelDhcpv4SrvTest, configReloadValid) {
 
     // This command should reload test8.json config.
     sendUnixCommand("{ \"command\": \"config-reload\" }", response);
-
     // Verify the configuration was successful. The config contains random
-    // socket name (/tmp/kea-<value-changing-each-time>/kea4.sock), so the
-    // hash will be different each time. As such, we can do simplified checks:
-    // - verify the "result": 0 is there
-    // - verify the "text": "Configuration successful." is there
-    EXPECT_NE(response.find("\"result\": 0"), std::string::npos);
-    EXPECT_NE(response.find("\"text\": \"Configuration successful.\""), std::string::npos);
-
-    // Check that the config was indeed applied.
-    const Subnet4Collection* subnets =
-        CfgMgr::instance().getCurrentCfg()->getCfgSubnets4()->getAll();
-    EXPECT_EQ(2, subnets->size());
-
-    ::remove("test8.json");
-}
-
-// Tests if config-reload attempts to reload a file and reports that the
-// file is loaded correctly.
-TEST_F(CtrlChannelDhcpv4SrvTest, configReloadDetectInterfaces) {
-    interfaces_ = "\"eth0\"";
-    IfacePtr eth0 = IfaceMgrTestConfig::createIface("eth0", ETH0_INDEX,
-                                                    "11:22:33:44:55:66");
-    auto detectIfaces = [&](bool update_only) {
-        if (!update_only) {
-            eth0->addAddress(IOAddress("10.0.0.1"));
-            eth0->addAddress(IOAddress("fe80::3a60:77ff:fed5:cdef"));
-            eth0->addAddress(IOAddress("2001:db8:1::1"));
-            IfaceMgr::instance().addInterface(eth0);
-        }
-        return (false);
-    };
-    IfaceMgr::instance().setDetectCallback(detectIfaces);
-    IfaceMgr::instance().clearIfaces();
-    IfaceMgr::instance().closeSockets();
-    IfaceMgr::instance().detectIfaces();
-    createUnixChannelServer();
-    std::string response;
-
-    // This is normally set to whatever value is passed to -c when the server is
-    // started, but we're not starting it that way, so need to set it by hand.
-    server_->setConfigFile("test8.json");
-
-    // Ok, enough fooling around. Let's create a valid config.
-    const std::string cfg_txt =
-        "{ \"Dhcp4\": {"
-        "    \"interfaces-config\": {"
-        "        \"interfaces\": [ \"eth1\" ]"
-        "    },"
-        "    \"subnet4\": ["
-        "        { \"id\": 1, \"subnet\": \"192.0.2.0/24\" },"
-        "        { \"id\": 2, \"subnet\": \"192.0.3.0/24\" }"
-        "     ],"
-        "    \"valid-lifetime\": 4000,"
-        "    \"lease-database\": {"
-        "       \"type\": \"memfile\", \"persist\": false }"
-        "} }";
-    ofstream f("test8.json", ios::trunc);
-    f << cfg_txt;
-    f.close();
-
-    IfacePtr eth1 = IfaceMgrTestConfig::createIface("eth1", ETH1_INDEX,
-                                                    "AA:BB:CC:DD:EE:FF");
-    auto detectUpdateIfaces = [&](bool update_only) {
-        if (!update_only) {
-            eth1->addAddress(IOAddress("192.0.2.3"));
-            eth1->addAddress(IOAddress("fe80::3a60:77ff:fed5:abcd"));
-            eth1->addAddress(IOAddress("3001:db8:100::1"));
-            IfaceMgr::instance().addInterface(eth1);
-        }
-        return (false);
-    };
-    IfaceMgr::instance().setDetectCallback(detectUpdateIfaces);
-
-    // This command should reload test8.json config.
-    sendUnixCommand("{ \"command\": \"config-reload\" }", response);
-
-    // Verify the configuration was successful. The config contains random
-    // socket name (/tmp/kea-<value-changing-each-time>/kea4.sock), so the
+    // socket name (/tmp/kea-<value-changing-each-time>/kea6.sock), so the
     // hash will be different each time. As such, we can do simplified checks:
     // - verify the "result": 0 is there
     // - verify the "text": "Configuration successful." is there
