@@ -267,13 +267,15 @@ BaseNetworkParser::parseDdnsParams(const data::ConstElementPtr& network_data,
         network->setDdnsUpdateOnRenew(getBoolean(network_data, "ddns-update-on-renew"));
     }
 
-    if (network_data->contains("ddns-use-conflict-resolution")) {
-        network->setDdnsUseConflictResolution(getBoolean(network_data, "ddns-use-conflict-resolution"));
-    }
-
     if (network_data->contains("ddns-ttl-percent")) {
         network->setDdnsTtlPercent(getDouble(network_data, "ddns-ttl-percent"));
     }
+
+    // For backward compatibility, ddns-conflict-resolution-mode is optional.
+    if (network_data->contains("ddns-conflict-resolution-mode")) {
+        network->setDdnsConflictResolutionMode(getString(network_data,
+                                                         "ddns-conflict-resolution-mode"));
+    }
 }
 
 void
@@ -281,9 +283,10 @@ BaseNetworkParser::parseAllocatorParams(const data::ConstElementPtr& network_dat
                                         NetworkPtr& network) {
     if (network_data->contains("allocator")) {
         auto allocator_type = getString(network_data, "allocator");
-        if ((allocator_type != "iterative") && (allocator_type != "random")) {
+        if ((allocator_type != "iterative") && (allocator_type != "random") &&
+            (allocator_type != "flq")) {
             // Unsupported allocator type used.
-            isc_throw(DhcpConfigError, "supported allocators are: iterative and random");
+            isc_throw(DhcpConfigError, "supported allocators are: iterative, random and flq");
         }
         network->setAllocatorType(allocator_type);
     }
@@ -294,9 +297,10 @@ BaseNetworkParser::parsePdAllocatorParams(const data::ConstElementPtr& network_d
                                           Network6Ptr& network) {
     if (network_data->contains("pd-allocator")) {
         auto allocator_type = getString(network_data, "pd-allocator");
-        if ((allocator_type != "iterative") && (allocator_type != "random")) {
+        if ((allocator_type != "iterative") && (allocator_type != "random") &&
+            (allocator_type != "flq")) {
             // Unsupported allocator type used.
-            isc_throw(DhcpConfigError, "supported allocators are: iterative and random");
+            isc_throw(DhcpConfigError, "supported allocators are: iterative, random and flq");
         }
         network->setPdAllocatorType(allocator_type);
     }
